
SNMP Simulator Control Plane
============================

SNMP Simulator Control Plane is a set of tools facilitating
automated, distributed and remotely controlled
`SNMP Simulator <http://snmplabs.com/snmpsim>`_ deployment.

Kudos to `inexio <https://github.com/inexio>`_ for inspiring and
sponsoring this project!

Documentation
-------------

.. toctree::
   :maxdepth: 2

   /architecture
   /deployment
   /usage

Download & Changelog
--------------------

Project source code and released packages can be downloaded from
`GitHub <https://github.com/etingof/snmpsim-control-plane/releases>`_
or `PyPI <https://pypi.org/project/snmpsim-control-plane/>`_.

We maintain a detailed log of changes:

.. toctree::
   :maxdepth: 1

   /changelog

License
-------

The SNMP Simulator Control Plane software is distributed under 2-clause
BSD license

.. toctree::
   :maxdepth: 1

   /license

Help and support
----------------

In case of questions or troubles using SNMP Simulator Control Plane software,
do not hesitate opening up an
`issue <https://github.com/etingof/snmpsim-control-plane/issues>`_ at GitHub
or ask on
`Stack Overflow <http://stackoverflow.com/questions/tagged/snmpsim>`_ .

Everyone is welcome to fork the repo and propose a feature or a fix!
